# eric7.MicroPython.BluetoothDialogs.BluetoothStatusDialog

Module implementing a dialog to show Bluetooth related status information.

### Global Attributes

None

### Classes

BluetoothStatusDialog | Class implementing a dialog to show Bluetooth related status information.

### Functions

None

## BluetoothStatusDialog

Class implementing a dialog to show Bluetooth related status information.

### Derived from

QDialog, Ui_BluetoothStatusDialog

### Class Attributes

None

### Class Methods

None

### Methods

BluetoothStatusDialog | Constructor

### Static Methods

None

#### BluetoothStatusDialog (Constructor)

BluetoothStatusDialog(status, parent=None)

Constructor

status (list of tuples of (str, str))
  status data to be show
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

Up